#!/bin/bash

# file: watch-x-config.sh
logfile="/var/log/userful-start.log"
ProgramName=`basename $0`

MAX_X_START_TIME=180
MIN_TIME_TO_WAIT=10
START_TIME=`date +%s`

sleep $MIN_TIME_TO_WAIT
echo "`date +"%b %d %T"` $ProgramName: Start watch-x-config.sh" >>  $logfile

while ! pgrep config-message && [ ! -e /tmp/ret-config-message ]; do
	NOW=`date +%s`
	TIME_TAKEN=$(( $NOW - $START_TIME ))

	if [ $TIME_TAKEN -gt $MAX_X_START_TIME ]; then
		echo "`date +"%b %d %T"` $ProgramName: Can't start config-message program. May normal X fail to start." >>  $logfile
		pkill -9 X 2> /dev/null
		sleep 2
		break
	fi
	sleep 1
done
